#!/bin/bash
# Server installation script for 
# eDokumenty on Debian Lenny
#
# @version 2.0
# @author: BetaSoft
#

INSTALL_DIR=$(pwd)

echo -ne "\033[01;32mCzy chcesz instalowac pakiety managerem apt-get? Zalecane y (y/n) \033[00m \n"
read APTYESNO
if [ "$APTYESNO" = "y" ]; then

#Dodatkowe repozytorium dla postgresql
cp conf/pgdg.list /etc/apt/sources.list.d/ 
apt-key add lib/ACCC4CF8.asc
sleep 5

apt-get update

# Base tools
apt-get -y install ssh
apt-get -y install vim
apt-get -y install mc
apt-get -y install nmap
apt-get -y install ngrep
apt-get -y install sed
apt-get -y install wget
apt-get -y install gzip
apt-get -y install adduser
apt-get -y install useradd
apt-get -y install bzip2
apt-get -y install unzip
apt-get -y install rsync
apt-get -y install less

# System tools
apt-get -y install sudo
apt-get -y install iptables
apt-get -y install cron
apt-get -y install iproute
apt-get -y install tcpdump
apt-get -y install ntpdate 

# Additional tools
apt-get -y install apt-show-versions
apt-get -y install gcc
apt-get -y install g++
apt-get -y install cpp
apt-get -y install make

# Backup tools
apt-get -y install mkisofs
apt-get -y install hdparm
apt-get -y install dvd+rw-tools
apt-get -y install mt-st
apt-get -y install smbfs
apt-get -y install autofs

# Processing tools
apt-get -y install imagemagick
apt-get -y install gs-common
apt-get -y install html2ps
apt-get -y install latex2rtf
apt-get -y install antiword
apt-get -y install gnuhtml2latex

# Services
apt-get -y --force-yes install postgresql-9.3
apt-get -y install apache2
apt-get -y install php5
apt-get -y install php5-cli
apt-get -y install php-pear
apt-get -y install php5-pgsql
apt-get -y install php5-imap
apt-get -y install php5-dev
apt-get -y install php5-gd
apt-get -y install php5-sybase
apt-get -y install php5-odbc

apt-get -y install subversion
apt-get -y install openssl
apt-get -y install ssl-cert

apt-get -y install abiword

fi

# Postfix
echo -ne "\033[01;32mCzy zainstalowac Postfix? (y/n) \033[00m \n"
read FAXYESNO
if [ "$FAXYESNO" = "y" ]; then
    apt-get install postfix
    apt-get install libsasl2-modules
fi

# Fax utils
echo -ne "\033[01;32mCzy zainstalowac hylafax server? (y/n) \033[00m \n"
read FAXYESNO
if [ "$FAXYESNO" = "y" ]; then
    apt-get install setserial
    apt-get install ppp
    apt-get install hylafax-server
    apt-get install hylafax-client
    apt-get install wvdial
fi

echo "Zakladanie kont i konfiguracja grup dla edokumenty"
# konta i grupy systemowe
adduser --ingroup users edokumenty 
groupadd edokumenty
adduser edokumenty edokumenty
adduser www-data edokumenty

echo "Aktywacja modulow Apache"
for module in php5 ssl rewrite userdir vhost_alias
do 
    a2enmod $module;
done

#enable ssl
a2ensite default-ssl

# Modyfikacje plików konfiguracyjnych
echo -ne "\033[01;32mCzy modyfikowac pliki konfiguracyjne (zalecane y)? (y/n) \033[00m \n"
read CONFYESNO
if [ "$CONFYESNO" = "y" ]; then

    cp conf/default /etc/apache2/sites-available/
    cp conf/default-ssl /etc/apache2/sites-available/
    echo "LimitRequestFieldSize 16384" >> /etc/apache2/apache2.conf

    # konfiguracja php
    cd /etc/php5/apache2
    vim -c '%s/;default_charset = "iso-8859-1"/default_charset = "utf-8"/' -c 'wq' php.ini
    vim -c '%s/memory_limit = [0-9]*M/memory_limit = 128M/' -c 'wq' php.ini
    vim -c '%s/upload_max_filesize = [0-9]*M/upload_max_filesize = 32M/' -c 'wq' php.ini
    vim -c '%s/post_max_size = [0-9]*M/post_max_size = 32M/' -c 'wq' php.ini
    vim -c '%s/;mbstring.internal_encoding = EUC-JP/mbstring.internal_encoding = UTF-8/' -c 'wq' php.ini
    vim -c '%s/enable_dl = Off/enable_dl = On/' -c 'wq' php.ini
    vim -c '%s/;error_log = php_errors.log/error_log = \/var\/log\/php_error.log/' -c 'wq' php.ini

    touch /var/log/php_error.log
    chown www-data:www-data /var/log/php_error.log

    # postgres 9.3 
    cd /etc/postgresql/9.3/main
    vim -c "%s/#default_with_oids = off/default_with_oids = on/" -c "wq" postgresql.conf
    vim -c "%s/#escape_string_warning = on/escape_string_warning = off/" -c "wq" postgresql.conf
    cp -p $INSTALL_DIR'/lib/pg_hba.conf' /etc/postgresql/9.3/main/
fi

# Przypisanie tych samych ustawień do php consolowego
ln -s /etc/php5/apache2/php.ini /etc/php5/cli/php.ini

echo "Utworzenie public_html i pozostałych katalogów oraz umożliwienie zapisu do nich na czas instalacji procesowi serwera"
cd $INSTALL_DIR

chgrp edokumenty ~edokumenty
chmod g+w ~edokumenty

mkdir -p ~edokumenty/public_html/apps/edokumenty
chgrp edokumenty ~edokumenty/public_html/apps/edokumenty
chmod g+w ~edokumenty/public_html/apps/edokumenty

cp lib/engine ~edokumenty/public_html/
chown edokumenty:users -R ~edokumenty/public_html

# Tworzenie użytkowników bazy danych (wszyscy z opcjami N)
echo "Tworzenie uzytkownika bazy danych - http (wszystkie opcje N)"
sudo -u postgres createuser --no-superuser --no-createdb --no-createrole http
echo "Tworzenie uzytkownika bazy danych - edokumenty (wszystkie opcje N)"
sudo -u postgres createuser --no-superuser --no-createdb --no-createrole edokumenty

# Tworzenie baz danych
echo "Tworzenie bazy edokumenty"
sudo -u postgres createdb -E UTF8 edokumenty -O edokumenty
sudo -u postgres createlang -d edokumenty plpgsql

# VPN
# cp lib/check_vpn.sh /etc/cron.hourly/

echo "Kopiowanie skryptu firewall"
cp lib/iptables.deb_rc.sh /etc/network/

echo "Konfiguracja domyslnego backupu - domyslne skrypty, ustawienia backapu i skrypty crona"
./bin/mk_backup_dirs.sh
cd $INSTALL_DIR
cp lib/backup/backup_db /etc/cron.daily/
cp lib/backup/backup_repos /etc/cron.daily/
cp lib/backup/backup_files /etc/cron.daily/

cp conf/exclude.conf /etc/backup
cp conf/backup.conf /etc/backup

# ustawienie czasu
#rdate -s ntp.task.gda.pl
# hwclock --systohc

# Pakiety PEAR
pear channel-update pear.php.net
pear install Console_Getopt
pear install Auth_SASL
pear install Mail_Mime 
pear install Net_SMTP
pear install Crypt_Rc4
pear install Date
pear install HTTP_Request
pear install Mail
pear install Mail_MimeDecode
pear install Net_SMTP
pear install Net_Socket
pear install Net_URL
pear install SOAP-0.12.0
pear install OLE-0.6.1
pear install Spreadsheet_Excel_Writer-0.9.2
pear install Mail_Queue
pear install HTML_Template_Flexy

# Instalacja dodatkowych modułów
echo -ne "\033[01;32mCzy chcesz instalowac moduly optimizer? (y/n) \033[00m \n"
read CONFYESNO
if [ "$CONFYESNO" = "y" ]; then
    # Zend Optimizer
    echo "Instalacja ZendOptimizer"
    ./bin/optimizer.sh
fi

apt-get -y purge php5-suhosin
rm /etc/apache2/mods-available/php5.conf
cp lib/php5.conf /etc/apache2/mods-available/

# Restart Apache i Postgres
echo "Restart apache"
sleep 3
/etc/init.d/apache2 restart


echo "Restart postgres"
sleep 1
/etc/init.d/postgresql restart


# TODO
# konfiguracja i sprawdzenie dostępu do bazy danych
# ustawienie dostępu do plików aby umożliwić zapis repository i config.inc
# najlepiej po wgraniu zip-a wykonać plik fixperms jako edokumenty
# wyłączyć katalog apps/edokumenty/var spod możliwości wykonywania skryptów php
# 


